@@ -2,6 +2,7 @@
 
 import httplib
 import json
+import time
 from pprint import pprint
 from fifo.helper import *
 
@@ -137,7 +138,18 @@ class Wiggle:
             conn = self.conn()
             conn.request('GET', newurl, '', self.headers)
             response = conn.getresponse()
-            if (response.status != 200):
+            vprint('Status (after redirect): ', response.status)
+            if (response.status == 404):
+                time.sleep(5)
+                conn = self.conn()
+                conn.request('GET', newurl, '', self.headers)
+                response = conn.getresponse()
+                vprint('Status (after reload): ', response.status)
+                if (response.status != 200):
+                    return False
+                else:
+                    return json.loads(response.read())
+            elif (response.status != 200):
                 return False
             else:
                 return json.loads(response.read())
@@ -153,7 +165,6 @@ class Wiggle:
         if isinstance(attr, str):
             attr = [attr]
         url = self._apiEndpoint + resource + '/' + entity + '/' + '/'.join(attr)
-        jbody = json.dumps(body)
         vprint('GET', url, '', self.headers)
         curlprint(self.host, 'GET', url, headers=self.headers)
         conn.request('GET', url, '', self.headers)
